# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1beta1NodeAllocatableResourceMapping(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allocation_multiplier': 'str',
        'capacity_key': 'str'
    }

    attribute_map = {
        'allocation_multiplier': 'allocationMultiplier',
        'capacity_key': 'capacityKey'
    }

    def __init__(self, allocation_multiplier=None, capacity_key=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1NodeAllocatableResourceMapping - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._allocation_multiplier = None
        self._capacity_key = None
        self.discriminator = None

        if allocation_multiplier is not None:
            self.allocation_multiplier = allocation_multiplier
        if capacity_key is not None:
            self.capacity_key = capacity_key

    @property
    def allocation_multiplier(self):
        """Gets the allocation_multiplier of this V1beta1NodeAllocatableResourceMapping.  # noqa: E501

        AllocationMultiplier is used as a multiplier for the allocated device count or the allocated capacity in the claim. It defaults to 1 if not specified. How the field is used also depends on whether `capacityKey` is set. 1.  If `capacityKey` is NOT set: `allocationMultiplier` multiplies the device count allocated to the claim.     a. A DRA driver representing each CPU core as a device would have        {ResourceName: \"cpu\", allocationMultiplier: \"2\"} in its        `nodeAllocatableResourceMappings`. If 4 devices are allocated to the claim,     4 * 2 CPUs would be considered as allocated and subtracted from the node's capacity.     b. A GPU device that needs additional node memory per GPU allocation would        have {ResourceName: \"memory\", allocationMultiplier: \"2Gi\"}.  Each allocated     GPU device instance of this type will account for 2Gi of memory.  2.  If `capacityKey` IS set: `allocationMultiplier` is multiplied by the amount of that capacity consumed.     The final node allocatable resource amount is `consumedCapacity[capacityKey]` * `allocationMultiplier`.     For example, if a Device's capacity \"dra.example.com/cores\" is consumed,     and each \"core\" provides 2 \"cpu\"s, the mapping would be:     {ResourceName: \"cpu\", capacityKey: \"dra.example.com/cores\", allocationMultiplier: \"2\"}.     If a claim consumes 8 \"dra.example.com/cores\", the CPU footprint is 8 * 2 = 16.  # noqa: E501

        :return: The allocation_multiplier of this V1beta1NodeAllocatableResourceMapping.  # noqa: E501
        :rtype: str
        """
        return self._allocation_multiplier

    @allocation_multiplier.setter
    def allocation_multiplier(self, allocation_multiplier):
        """Sets the allocation_multiplier of this V1beta1NodeAllocatableResourceMapping.

        AllocationMultiplier is used as a multiplier for the allocated device count or the allocated capacity in the claim. It defaults to 1 if not specified. How the field is used also depends on whether `capacityKey` is set. 1.  If `capacityKey` is NOT set: `allocationMultiplier` multiplies the device count allocated to the claim.     a. A DRA driver representing each CPU core as a device would have        {ResourceName: \"cpu\", allocationMultiplier: \"2\"} in its        `nodeAllocatableResourceMappings`. If 4 devices are allocated to the claim,     4 * 2 CPUs would be considered as allocated and subtracted from the node's capacity.     b. A GPU device that needs additional node memory per GPU allocation would        have {ResourceName: \"memory\", allocationMultiplier: \"2Gi\"}.  Each allocated     GPU device instance of this type will account for 2Gi of memory.  2.  If `capacityKey` IS set: `allocationMultiplier` is multiplied by the amount of that capacity consumed.     The final node allocatable resource amount is `consumedCapacity[capacityKey]` * `allocationMultiplier`.     For example, if a Device's capacity \"dra.example.com/cores\" is consumed,     and each \"core\" provides 2 \"cpu\"s, the mapping would be:     {ResourceName: \"cpu\", capacityKey: \"dra.example.com/cores\", allocationMultiplier: \"2\"}.     If a claim consumes 8 \"dra.example.com/cores\", the CPU footprint is 8 * 2 = 16.  # noqa: E501

        :param allocation_multiplier: The allocation_multiplier of this V1beta1NodeAllocatableResourceMapping.  # noqa: E501
        :type allocation_multiplier: str
        """

        self._allocation_multiplier = allocation_multiplier

    @property
    def capacity_key(self):
        """Gets the capacity_key of this V1beta1NodeAllocatableResourceMapping.  # noqa: E501

        CapacityKey references a capacity name defined as a key in the `spec.devices[*].capacity` map. When this field is set, the value associated with this key in the `status.allocation.devices.results[*].consumedCapacity` map (for a specific claim allocation) determines the base quantity for the node allocatable resource. If `allocationMultiplier` is also set, it is multiplied with the base quantity. For example, if `spec.devices[*].capacity` has an entry \"dra.example.com/memory\": \"128Gi\", and this field is set to \"dra.example.com/memory\", then for a claim allocation that consumes { \"dra.example.com/memory\": \"4Gi\" } the base quantity for the node allocatable resource mapping will be \"4Gi\", and `allocationMultiplier` should be omitted or set to \"1\".  # noqa: E501

        :return: The capacity_key of this V1beta1NodeAllocatableResourceMapping.  # noqa: E501
        :rtype: str
        """
        return self._capacity_key

    @capacity_key.setter
    def capacity_key(self, capacity_key):
        """Sets the capacity_key of this V1beta1NodeAllocatableResourceMapping.

        CapacityKey references a capacity name defined as a key in the `spec.devices[*].capacity` map. When this field is set, the value associated with this key in the `status.allocation.devices.results[*].consumedCapacity` map (for a specific claim allocation) determines the base quantity for the node allocatable resource. If `allocationMultiplier` is also set, it is multiplied with the base quantity. For example, if `spec.devices[*].capacity` has an entry \"dra.example.com/memory\": \"128Gi\", and this field is set to \"dra.example.com/memory\", then for a claim allocation that consumes { \"dra.example.com/memory\": \"4Gi\" } the base quantity for the node allocatable resource mapping will be \"4Gi\", and `allocationMultiplier` should be omitted or set to \"1\".  # noqa: E501

        :param capacity_key: The capacity_key of this V1beta1NodeAllocatableResourceMapping.  # noqa: E501
        :type capacity_key: str
        """

        self._capacity_key = capacity_key

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1NodeAllocatableResourceMapping):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1NodeAllocatableResourceMapping):
            return True

        return self.to_dict() != other.to_dict()
