# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1alpha3ResourcePoolStatusRequestStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conditions': 'list[V1Condition]',
        'pool_count': 'int',
        'pools': 'list[V1alpha3PoolStatus]'
    }

    attribute_map = {
        'conditions': 'conditions',
        'pool_count': 'poolCount',
        'pools': 'pools'
    }

    def __init__(self, conditions=None, pool_count=None, pools=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha3ResourcePoolStatusRequestStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._conditions = None
        self._pool_count = None
        self._pools = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions
        self.pool_count = pool_count
        if pools is not None:
            self.pools = pools

    @property
    def conditions(self):
        """Gets the conditions of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501

        Conditions provide information about the state of the request. A condition with type=Complete or type=Failed will always be set when the status is populated.  Known condition types: - \"Complete\": True when the request has been processed successfully - \"Failed\": True when the request could not be processed  # noqa: E501

        :return: The conditions of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501
        :rtype: list[V1Condition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1alpha3ResourcePoolStatusRequestStatus.

        Conditions provide information about the state of the request. A condition with type=Complete or type=Failed will always be set when the status is populated.  Known condition types: - \"Complete\": True when the request has been processed successfully - \"Failed\": True when the request could not be processed  # noqa: E501

        :param conditions: The conditions of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501
        :type conditions: list[V1Condition]
        """

        self._conditions = conditions

    @property
    def pool_count(self):
        """Gets the pool_count of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501

        PoolCount is the total number of pools that matched the filter criteria, regardless of truncation. This helps users understand how many pools exist even when the response is truncated. A value of 0 means no pools matched the filter criteria.  # noqa: E501

        :return: The pool_count of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501
        :rtype: int
        """
        return self._pool_count

    @pool_count.setter
    def pool_count(self, pool_count):
        """Sets the pool_count of this V1alpha3ResourcePoolStatusRequestStatus.

        PoolCount is the total number of pools that matched the filter criteria, regardless of truncation. This helps users understand how many pools exist even when the response is truncated. A value of 0 means no pools matched the filter criteria.  # noqa: E501

        :param pool_count: The pool_count of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501
        :type pool_count: int
        """
        if self.local_vars_configuration.client_side_validation and pool_count is None:  # noqa: E501
            raise ValueError("Invalid value for `pool_count`, must not be `None`")  # noqa: E501

        self._pool_count = pool_count

    @property
    def pools(self):
        """Gets the pools of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501

        Pools contains the first `spec.limit` matching pools, sorted by driver then pool name. If `len(pools) < poolCount`, the list was truncated. When omitted, no pools matched the request filters.  # noqa: E501

        :return: The pools of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501
        :rtype: list[V1alpha3PoolStatus]
        """
        return self._pools

    @pools.setter
    def pools(self, pools):
        """Sets the pools of this V1alpha3ResourcePoolStatusRequestStatus.

        Pools contains the first `spec.limit` matching pools, sorted by driver then pool name. If `len(pools) < poolCount`, the list was truncated. When omitted, no pools matched the request filters.  # noqa: E501

        :param pools: The pools of this V1alpha3ResourcePoolStatusRequestStatus.  # noqa: E501
        :type pools: list[V1alpha3PoolStatus]
        """

        self._pools = pools

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha3ResourcePoolStatusRequestStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha3ResourcePoolStatusRequestStatus):
            return True

        return self.to_dict() != other.to_dict()
