# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1beta2DeviceAttribute(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bool': 'bool',
        'bools': 'list[bool]',
        'int': 'int',
        'ints': 'list[int]',
        'string': 'str',
        'strings': 'list[str]',
        'version': 'str',
        'versions': 'list[str]'
    }

    attribute_map = {
        'bool': 'bool',
        'bools': 'bools',
        'int': 'int',
        'ints': 'ints',
        'string': 'string',
        'strings': 'strings',
        'version': 'version',
        'versions': 'versions'
    }

    def __init__(self, bool=None, bools=None, int=None, ints=None, string=None, strings=None, version=None, versions=None, local_vars_configuration=None):  # noqa: E501
        """V1beta2DeviceAttribute - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._bool = None
        self._bools = None
        self._int = None
        self._ints = None
        self._string = None
        self._strings = None
        self._version = None
        self._versions = None
        self.discriminator = None

        if bool is not None:
            self.bool = bool
        if bools is not None:
            self.bools = bools
        if int is not None:
            self.int = int
        if ints is not None:
            self.ints = ints
        if string is not None:
            self.string = string
        if strings is not None:
            self.strings = strings
        if version is not None:
            self.version = version
        if versions is not None:
            self.versions = versions

    @property
    def bool(self):
        """Gets the bool of this V1beta2DeviceAttribute.  # noqa: E501

        BoolValue is a true/false value.  # noqa: E501

        :return: The bool of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: bool
        """
        return self._bool

    @bool.setter
    def bool(self, bool):
        """Sets the bool of this V1beta2DeviceAttribute.

        BoolValue is a true/false value.  # noqa: E501

        :param bool: The bool of this V1beta2DeviceAttribute.  # noqa: E501
        :type bool: bool
        """

        self._bool = bool

    @property
    def bools(self):
        """Gets the bools of this V1beta2DeviceAttribute.  # noqa: E501

        BoolValues is a non-empty list of true/false values.  # noqa: E501

        :return: The bools of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: list[bool]
        """
        return self._bools

    @bools.setter
    def bools(self, bools):
        """Sets the bools of this V1beta2DeviceAttribute.

        BoolValues is a non-empty list of true/false values.  # noqa: E501

        :param bools: The bools of this V1beta2DeviceAttribute.  # noqa: E501
        :type bools: list[bool]
        """

        self._bools = bools

    @property
    def int(self):
        """Gets the int of this V1beta2DeviceAttribute.  # noqa: E501

        IntValue is a number.  # noqa: E501

        :return: The int of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: int
        """
        return self._int

    @int.setter
    def int(self, int):
        """Sets the int of this V1beta2DeviceAttribute.

        IntValue is a number.  # noqa: E501

        :param int: The int of this V1beta2DeviceAttribute.  # noqa: E501
        :type int: int
        """

        self._int = int

    @property
    def ints(self):
        """Gets the ints of this V1beta2DeviceAttribute.  # noqa: E501

        IntValues is a non-empty list of numbers.  This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.  # noqa: E501

        :return: The ints of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: list[int]
        """
        return self._ints

    @ints.setter
    def ints(self, ints):
        """Sets the ints of this V1beta2DeviceAttribute.

        IntValues is a non-empty list of numbers.  This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.  # noqa: E501

        :param ints: The ints of this V1beta2DeviceAttribute.  # noqa: E501
        :type ints: list[int]
        """

        self._ints = ints

    @property
    def string(self):
        """Gets the string of this V1beta2DeviceAttribute.  # noqa: E501

        StringValue is a string. Must not be longer than 64 characters.  # noqa: E501

        :return: The string of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: str
        """
        return self._string

    @string.setter
    def string(self, string):
        """Sets the string of this V1beta2DeviceAttribute.

        StringValue is a string. Must not be longer than 64 characters.  # noqa: E501

        :param string: The string of this V1beta2DeviceAttribute.  # noqa: E501
        :type string: str
        """

        self._string = string

    @property
    def strings(self):
        """Gets the strings of this V1beta2DeviceAttribute.  # noqa: E501

        StringValues is a non-empty list of strings. Each string must not be longer than 64 characters.  This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.  # noqa: E501

        :return: The strings of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: list[str]
        """
        return self._strings

    @strings.setter
    def strings(self, strings):
        """Sets the strings of this V1beta2DeviceAttribute.

        StringValues is a non-empty list of strings. Each string must not be longer than 64 characters.  This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.  # noqa: E501

        :param strings: The strings of this V1beta2DeviceAttribute.  # noqa: E501
        :type strings: list[str]
        """

        self._strings = strings

    @property
    def version(self):
        """Gets the version of this V1beta2DeviceAttribute.  # noqa: E501

        VersionValue is a semantic version according to semver.org spec 2.0.0. Must not be longer than 64 characters.  # noqa: E501

        :return: The version of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this V1beta2DeviceAttribute.

        VersionValue is a semantic version according to semver.org spec 2.0.0. Must not be longer than 64 characters.  # noqa: E501

        :param version: The version of this V1beta2DeviceAttribute.  # noqa: E501
        :type version: str
        """

        self._version = version

    @property
    def versions(self):
        """Gets the versions of this V1beta2DeviceAttribute.  # noqa: E501

        VersionValues is a non-empty list of semantic versions according to semver.org spec 2.0.0. Each version string must not be longer than 64 characters.  This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.  # noqa: E501

        :return: The versions of this V1beta2DeviceAttribute.  # noqa: E501
        :rtype: list[str]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this V1beta2DeviceAttribute.

        VersionValues is a non-empty list of semantic versions according to semver.org spec 2.0.0. Each version string must not be longer than 64 characters.  This is an alpha field and requires enabling the DRAListTypeAttributes feature gate.  # noqa: E501

        :param versions: The versions of this V1beta2DeviceAttribute.  # noqa: E501
        :type versions: list[str]
        """

        self._versions = versions

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta2DeviceAttribute):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta2DeviceAttribute):
            return True

        return self.to_dict() != other.to_dict()
