# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1beta2Device(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'all_nodes': 'bool',
        'allow_multiple_allocations': 'bool',
        'attributes': 'dict[str, V1beta2DeviceAttribute]',
        'binding_conditions': 'list[str]',
        'binding_failure_conditions': 'list[str]',
        'binds_to_node': 'bool',
        'capacity': 'dict[str, V1beta2DeviceCapacity]',
        'consumes_counters': 'list[V1beta2DeviceCounterConsumption]',
        'name': 'str',
        'node_allocatable_resource_mappings': 'dict[str, V1beta2NodeAllocatableResourceMapping]',
        'node_name': 'str',
        'node_selector': 'V1NodeSelector',
        'taints': 'list[V1beta2DeviceTaint]'
    }

    attribute_map = {
        'all_nodes': 'allNodes',
        'allow_multiple_allocations': 'allowMultipleAllocations',
        'attributes': 'attributes',
        'binding_conditions': 'bindingConditions',
        'binding_failure_conditions': 'bindingFailureConditions',
        'binds_to_node': 'bindsToNode',
        'capacity': 'capacity',
        'consumes_counters': 'consumesCounters',
        'name': 'name',
        'node_allocatable_resource_mappings': 'nodeAllocatableResourceMappings',
        'node_name': 'nodeName',
        'node_selector': 'nodeSelector',
        'taints': 'taints'
    }

    def __init__(self, all_nodes=None, allow_multiple_allocations=None, attributes=None, binding_conditions=None, binding_failure_conditions=None, binds_to_node=None, capacity=None, consumes_counters=None, name=None, node_allocatable_resource_mappings=None, node_name=None, node_selector=None, taints=None, local_vars_configuration=None):  # noqa: E501
        """V1beta2Device - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._all_nodes = None
        self._allow_multiple_allocations = None
        self._attributes = None
        self._binding_conditions = None
        self._binding_failure_conditions = None
        self._binds_to_node = None
        self._capacity = None
        self._consumes_counters = None
        self._name = None
        self._node_allocatable_resource_mappings = None
        self._node_name = None
        self._node_selector = None
        self._taints = None
        self.discriminator = None

        if all_nodes is not None:
            self.all_nodes = all_nodes
        if allow_multiple_allocations is not None:
            self.allow_multiple_allocations = allow_multiple_allocations
        if attributes is not None:
            self.attributes = attributes
        if binding_conditions is not None:
            self.binding_conditions = binding_conditions
        if binding_failure_conditions is not None:
            self.binding_failure_conditions = binding_failure_conditions
        if binds_to_node is not None:
            self.binds_to_node = binds_to_node
        if capacity is not None:
            self.capacity = capacity
        if consumes_counters is not None:
            self.consumes_counters = consumes_counters
        self.name = name
        if node_allocatable_resource_mappings is not None:
            self.node_allocatable_resource_mappings = node_allocatable_resource_mappings
        if node_name is not None:
            self.node_name = node_name
        if node_selector is not None:
            self.node_selector = node_selector
        if taints is not None:
            self.taints = taints

    @property
    def all_nodes(self):
        """Gets the all_nodes of this V1beta2Device.  # noqa: E501

        AllNodes indicates that all nodes have access to the device.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :return: The all_nodes of this V1beta2Device.  # noqa: E501
        :rtype: bool
        """
        return self._all_nodes

    @all_nodes.setter
    def all_nodes(self, all_nodes):
        """Sets the all_nodes of this V1beta2Device.

        AllNodes indicates that all nodes have access to the device.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :param all_nodes: The all_nodes of this V1beta2Device.  # noqa: E501
        :type all_nodes: bool
        """

        self._all_nodes = all_nodes

    @property
    def allow_multiple_allocations(self):
        """Gets the allow_multiple_allocations of this V1beta2Device.  # noqa: E501

        AllowMultipleAllocations marks whether the device is allowed to be allocated to multiple DeviceRequests.  If AllowMultipleAllocations is set to true, the device can be allocated more than once, and all of its capacity is consumable, regardless of whether the requestPolicy is defined or not.  # noqa: E501

        :return: The allow_multiple_allocations of this V1beta2Device.  # noqa: E501
        :rtype: bool
        """
        return self._allow_multiple_allocations

    @allow_multiple_allocations.setter
    def allow_multiple_allocations(self, allow_multiple_allocations):
        """Sets the allow_multiple_allocations of this V1beta2Device.

        AllowMultipleAllocations marks whether the device is allowed to be allocated to multiple DeviceRequests.  If AllowMultipleAllocations is set to true, the device can be allocated more than once, and all of its capacity is consumable, regardless of whether the requestPolicy is defined or not.  # noqa: E501

        :param allow_multiple_allocations: The allow_multiple_allocations of this V1beta2Device.  # noqa: E501
        :type allow_multiple_allocations: bool
        """

        self._allow_multiple_allocations = allow_multiple_allocations

    @property
    def attributes(self):
        """Gets the attributes of this V1beta2Device.  # noqa: E501

        Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :return: The attributes of this V1beta2Device.  # noqa: E501
        :rtype: dict[str, V1beta2DeviceAttribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this V1beta2Device.

        Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :param attributes: The attributes of this V1beta2Device.  # noqa: E501
        :type attributes: dict[str, V1beta2DeviceAttribute]
        """

        self._attributes = attributes

    @property
    def binding_conditions(self):
        """Gets the binding_conditions of this V1beta2Device.  # noqa: E501

        BindingConditions defines the conditions for proceeding with binding. All of these conditions must be set in the per-device status conditions with a value of True to proceed with binding the pod to the node while scheduling the pod.  The maximum number of binding conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :return: The binding_conditions of this V1beta2Device.  # noqa: E501
        :rtype: list[str]
        """
        return self._binding_conditions

    @binding_conditions.setter
    def binding_conditions(self, binding_conditions):
        """Sets the binding_conditions of this V1beta2Device.

        BindingConditions defines the conditions for proceeding with binding. All of these conditions must be set in the per-device status conditions with a value of True to proceed with binding the pod to the node while scheduling the pod.  The maximum number of binding conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :param binding_conditions: The binding_conditions of this V1beta2Device.  # noqa: E501
        :type binding_conditions: list[str]
        """

        self._binding_conditions = binding_conditions

    @property
    def binding_failure_conditions(self):
        """Gets the binding_failure_conditions of this V1beta2Device.  # noqa: E501

        BindingFailureConditions defines the conditions for binding failure. They may be set in the per-device status conditions. If any is set to \"True\", a binding failure occurred.  The maximum number of binding failure conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :return: The binding_failure_conditions of this V1beta2Device.  # noqa: E501
        :rtype: list[str]
        """
        return self._binding_failure_conditions

    @binding_failure_conditions.setter
    def binding_failure_conditions(self, binding_failure_conditions):
        """Sets the binding_failure_conditions of this V1beta2Device.

        BindingFailureConditions defines the conditions for binding failure. They may be set in the per-device status conditions. If any is set to \"True\", a binding failure occurred.  The maximum number of binding failure conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :param binding_failure_conditions: The binding_failure_conditions of this V1beta2Device.  # noqa: E501
        :type binding_failure_conditions: list[str]
        """

        self._binding_failure_conditions = binding_failure_conditions

    @property
    def binds_to_node(self):
        """Gets the binds_to_node of this V1beta2Device.  # noqa: E501

        BindsToNode indicates if the usage of an allocation involving this device has to be limited to exactly the node that was chosen when allocating the claim. If set to true, the scheduler will set the ResourceClaim.Status.Allocation.NodeSelector to match the node where the allocation was made.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :return: The binds_to_node of this V1beta2Device.  # noqa: E501
        :rtype: bool
        """
        return self._binds_to_node

    @binds_to_node.setter
    def binds_to_node(self, binds_to_node):
        """Sets the binds_to_node of this V1beta2Device.

        BindsToNode indicates if the usage of an allocation involving this device has to be limited to exactly the node that was chosen when allocating the claim. If set to true, the scheduler will set the ResourceClaim.Status.Allocation.NodeSelector to match the node where the allocation was made.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :param binds_to_node: The binds_to_node of this V1beta2Device.  # noqa: E501
        :type binds_to_node: bool
        """

        self._binds_to_node = binds_to_node

    @property
    def capacity(self):
        """Gets the capacity of this V1beta2Device.  # noqa: E501

        Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :return: The capacity of this V1beta2Device.  # noqa: E501
        :rtype: dict[str, V1beta2DeviceCapacity]
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this V1beta2Device.

        Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :param capacity: The capacity of this V1beta2Device.  # noqa: E501
        :type capacity: dict[str, V1beta2DeviceCapacity]
        """

        self._capacity = capacity

    @property
    def consumes_counters(self):
        """Gets the consumes_counters of this V1beta2Device.  # noqa: E501

        ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.  There can only be a single entry per counterSet.  The maximum number of device counter consumptions per device is 2.  # noqa: E501

        :return: The consumes_counters of this V1beta2Device.  # noqa: E501
        :rtype: list[V1beta2DeviceCounterConsumption]
        """
        return self._consumes_counters

    @consumes_counters.setter
    def consumes_counters(self, consumes_counters):
        """Sets the consumes_counters of this V1beta2Device.

        ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.  There can only be a single entry per counterSet.  The maximum number of device counter consumptions per device is 2.  # noqa: E501

        :param consumes_counters: The consumes_counters of this V1beta2Device.  # noqa: E501
        :type consumes_counters: list[V1beta2DeviceCounterConsumption]
        """

        self._consumes_counters = consumes_counters

    @property
    def name(self):
        """Gets the name of this V1beta2Device.  # noqa: E501

        Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.  # noqa: E501

        :return: The name of this V1beta2Device.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta2Device.

        Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.  # noqa: E501

        :param name: The name of this V1beta2Device.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def node_allocatable_resource_mappings(self):
        """Gets the node_allocatable_resource_mappings of this V1beta2Device.  # noqa: E501

        NodeAllocatableResourceMappings defines the mapping of node resources that are managed by the DRA driver exposing this device. This includes resources currently reported in v1.Node `status.allocatable` that are not extended resources (see https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#extended-resources). Examples include \"cpu\", \"memory\", \"ephemeral-storage\", and hugepages. In addition to standard requests made through the Pod `spec`, these resources can also be requested through claims and allocated by the DRA driver. For example, a CPU DRA driver might allocate exclusive CPUs or auxiliary node memory dependencies of an accelerator device. The keys of this map are the node-allocatable resource names (e.g., \"cpu\", \"memory\"). Extended resource names are not permitted as keys.  # noqa: E501

        :return: The node_allocatable_resource_mappings of this V1beta2Device.  # noqa: E501
        :rtype: dict[str, V1beta2NodeAllocatableResourceMapping]
        """
        return self._node_allocatable_resource_mappings

    @node_allocatable_resource_mappings.setter
    def node_allocatable_resource_mappings(self, node_allocatable_resource_mappings):
        """Sets the node_allocatable_resource_mappings of this V1beta2Device.

        NodeAllocatableResourceMappings defines the mapping of node resources that are managed by the DRA driver exposing this device. This includes resources currently reported in v1.Node `status.allocatable` that are not extended resources (see https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#extended-resources). Examples include \"cpu\", \"memory\", \"ephemeral-storage\", and hugepages. In addition to standard requests made through the Pod `spec`, these resources can also be requested through claims and allocated by the DRA driver. For example, a CPU DRA driver might allocate exclusive CPUs or auxiliary node memory dependencies of an accelerator device. The keys of this map are the node-allocatable resource names (e.g., \"cpu\", \"memory\"). Extended resource names are not permitted as keys.  # noqa: E501

        :param node_allocatable_resource_mappings: The node_allocatable_resource_mappings of this V1beta2Device.  # noqa: E501
        :type node_allocatable_resource_mappings: dict[str, V1beta2NodeAllocatableResourceMapping]
        """

        self._node_allocatable_resource_mappings = node_allocatable_resource_mappings

    @property
    def node_name(self):
        """Gets the node_name of this V1beta2Device.  # noqa: E501

        NodeName identifies the node where the device is available.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :return: The node_name of this V1beta2Device.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this V1beta2Device.

        NodeName identifies the node where the device is available.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :param node_name: The node_name of this V1beta2Device.  # noqa: E501
        :type node_name: str
        """

        self._node_name = node_name

    @property
    def node_selector(self):
        """Gets the node_selector of this V1beta2Device.  # noqa: E501


        :return: The node_selector of this V1beta2Device.  # noqa: E501
        :rtype: V1NodeSelector
        """
        return self._node_selector

    @node_selector.setter
    def node_selector(self, node_selector):
        """Sets the node_selector of this V1beta2Device.


        :param node_selector: The node_selector of this V1beta2Device.  # noqa: E501
        :type node_selector: V1NodeSelector
        """

        self._node_selector = node_selector

    @property
    def taints(self):
        """Gets the taints of this V1beta2Device.  # noqa: E501

        If specified, these are the driver-defined taints.  The maximum number of taints is 16. If taints are set for any device in a ResourceSlice, then the maximum number of allowed devices per ResourceSlice is 64 instead of 128.  This is a beta field and requires enabling the DRADeviceTaints feature gate.  # noqa: E501

        :return: The taints of this V1beta2Device.  # noqa: E501
        :rtype: list[V1beta2DeviceTaint]
        """
        return self._taints

    @taints.setter
    def taints(self, taints):
        """Sets the taints of this V1beta2Device.

        If specified, these are the driver-defined taints.  The maximum number of taints is 16. If taints are set for any device in a ResourceSlice, then the maximum number of allowed devices per ResourceSlice is 64 instead of 128.  This is a beta field and requires enabling the DRADeviceTaints feature gate.  # noqa: E501

        :param taints: The taints of this V1beta2Device.  # noqa: E501
        :type taints: list[V1beta2DeviceTaint]
        """

        self._taints = taints

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta2Device):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta2Device):
            return True

        return self.to_dict() != other.to_dict()
