# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1alpha1ServerStorageVersion(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_server_id': 'str',
        'decodable_versions': 'list[str]',
        'encoding_version': 'str',
        'served_versions': 'list[str]'
    }

    attribute_map = {
        'api_server_id': 'apiServerID',
        'decodable_versions': 'decodableVersions',
        'encoding_version': 'encodingVersion',
        'served_versions': 'servedVersions'
    }

    def __init__(self, api_server_id=None, decodable_versions=None, encoding_version=None, served_versions=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha1ServerStorageVersion - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._api_server_id = None
        self._decodable_versions = None
        self._encoding_version = None
        self._served_versions = None
        self.discriminator = None

        self.api_server_id = api_server_id
        self.decodable_versions = decodable_versions
        self.encoding_version = encoding_version
        if served_versions is not None:
            self.served_versions = served_versions

    @property
    def api_server_id(self):
        """Gets the api_server_id of this V1alpha1ServerStorageVersion.  # noqa: E501

        apiServerID is the ID of the reporting API server.  # noqa: E501

        :return: The api_server_id of this V1alpha1ServerStorageVersion.  # noqa: E501
        :rtype: str
        """
        return self._api_server_id

    @api_server_id.setter
    def api_server_id(self, api_server_id):
        """Sets the api_server_id of this V1alpha1ServerStorageVersion.

        apiServerID is the ID of the reporting API server.  # noqa: E501

        :param api_server_id: The api_server_id of this V1alpha1ServerStorageVersion.  # noqa: E501
        :type api_server_id: str
        """
        if self.local_vars_configuration.client_side_validation and api_server_id is None:  # noqa: E501
            raise ValueError("Invalid value for `api_server_id`, must not be `None`")  # noqa: E501

        self._api_server_id = api_server_id

    @property
    def decodable_versions(self):
        """Gets the decodable_versions of this V1alpha1ServerStorageVersion.  # noqa: E501

        decodableVersions are the encoding versions the API server can handle to decode. The API server can decode objects encoded in these versions. The encodingVersion must be included in the decodableVersions.  # noqa: E501

        :return: The decodable_versions of this V1alpha1ServerStorageVersion.  # noqa: E501
        :rtype: list[str]
        """
        return self._decodable_versions

    @decodable_versions.setter
    def decodable_versions(self, decodable_versions):
        """Sets the decodable_versions of this V1alpha1ServerStorageVersion.

        decodableVersions are the encoding versions the API server can handle to decode. The API server can decode objects encoded in these versions. The encodingVersion must be included in the decodableVersions.  # noqa: E501

        :param decodable_versions: The decodable_versions of this V1alpha1ServerStorageVersion.  # noqa: E501
        :type decodable_versions: list[str]
        """
        if self.local_vars_configuration.client_side_validation and decodable_versions is None:  # noqa: E501
            raise ValueError("Invalid value for `decodable_versions`, must not be `None`")  # noqa: E501

        self._decodable_versions = decodable_versions

    @property
    def encoding_version(self):
        """Gets the encoding_version of this V1alpha1ServerStorageVersion.  # noqa: E501

        encodingVersion the API server encodes the object to when persisting it in the backend (e.g., etcd).  # noqa: E501

        :return: The encoding_version of this V1alpha1ServerStorageVersion.  # noqa: E501
        :rtype: str
        """
        return self._encoding_version

    @encoding_version.setter
    def encoding_version(self, encoding_version):
        """Sets the encoding_version of this V1alpha1ServerStorageVersion.

        encodingVersion the API server encodes the object to when persisting it in the backend (e.g., etcd).  # noqa: E501

        :param encoding_version: The encoding_version of this V1alpha1ServerStorageVersion.  # noqa: E501
        :type encoding_version: str
        """
        if self.local_vars_configuration.client_side_validation and encoding_version is None:  # noqa: E501
            raise ValueError("Invalid value for `encoding_version`, must not be `None`")  # noqa: E501

        self._encoding_version = encoding_version

    @property
    def served_versions(self):
        """Gets the served_versions of this V1alpha1ServerStorageVersion.  # noqa: E501

        servedVersions lists all versions the API server can serve. DecodableVersions must include all ServedVersions.  # noqa: E501

        :return: The served_versions of this V1alpha1ServerStorageVersion.  # noqa: E501
        :rtype: list[str]
        """
        return self._served_versions

    @served_versions.setter
    def served_versions(self, served_versions):
        """Sets the served_versions of this V1alpha1ServerStorageVersion.

        servedVersions lists all versions the API server can serve. DecodableVersions must include all ServedVersions.  # noqa: E501

        :param served_versions: The served_versions of this V1alpha1ServerStorageVersion.  # noqa: E501
        :type served_versions: list[str]
        """

        self._served_versions = served_versions

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha1ServerStorageVersion):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha1ServerStorageVersion):
            return True

        return self.to_dict() != other.to_dict()
