# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1alpha3DeviceTaintSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device': 'str',
        'driver': 'str',
        'pool': 'str'
    }

    attribute_map = {
        'device': 'device',
        'driver': 'driver',
        'pool': 'pool'
    }

    def __init__(self, device=None, driver=None, pool=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha3DeviceTaintSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._device = None
        self._driver = None
        self._pool = None
        self.discriminator = None

        if device is not None:
            self.device = device
        if driver is not None:
            self.driver = driver
        if pool is not None:
            self.pool = pool

    @property
    def device(self):
        """Gets the device of this V1alpha3DeviceTaintSelector.  # noqa: E501

        If device is set, only devices with that name are selected. This field corresponds to slice.spec.devices[].name.  Setting also driver and pool may be required to avoid ambiguity, but is not required.  # noqa: E501

        :return: The device of this V1alpha3DeviceTaintSelector.  # noqa: E501
        :rtype: str
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this V1alpha3DeviceTaintSelector.

        If device is set, only devices with that name are selected. This field corresponds to slice.spec.devices[].name.  Setting also driver and pool may be required to avoid ambiguity, but is not required.  # noqa: E501

        :param device: The device of this V1alpha3DeviceTaintSelector.  # noqa: E501
        :type device: str
        """

        self._device = device

    @property
    def driver(self):
        """Gets the driver of this V1alpha3DeviceTaintSelector.  # noqa: E501

        If driver is set, only devices from that driver are selected. This fields corresponds to slice.spec.driver.  # noqa: E501

        :return: The driver of this V1alpha3DeviceTaintSelector.  # noqa: E501
        :rtype: str
        """
        return self._driver

    @driver.setter
    def driver(self, driver):
        """Sets the driver of this V1alpha3DeviceTaintSelector.

        If driver is set, only devices from that driver are selected. This fields corresponds to slice.spec.driver.  # noqa: E501

        :param driver: The driver of this V1alpha3DeviceTaintSelector.  # noqa: E501
        :type driver: str
        """

        self._driver = driver

    @property
    def pool(self):
        """Gets the pool of this V1alpha3DeviceTaintSelector.  # noqa: E501

        If pool is set, only devices in that pool are selected.  Also setting the driver name may be useful to avoid ambiguity when different drivers use the same pool name, but this is not required because selecting pools from different drivers may also be useful, for example when drivers with node-local devices use the node name as their pool name.  # noqa: E501

        :return: The pool of this V1alpha3DeviceTaintSelector.  # noqa: E501
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """Sets the pool of this V1alpha3DeviceTaintSelector.

        If pool is set, only devices in that pool are selected.  Also setting the driver name may be useful to avoid ambiguity when different drivers use the same pool name, but this is not required because selecting pools from different drivers may also be useful, for example when drivers with node-local devices use the node name as their pool name.  # noqa: E501

        :param pool: The pool of this V1alpha3DeviceTaintSelector.  # noqa: E501
        :type pool: str
        """

        self._pool = pool

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha3DeviceTaintSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha3DeviceTaintSelector):
            return True

        return self.to_dict() != other.to_dict()
