# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1DeviceClaimConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'opaque': 'V1OpaqueDeviceConfiguration',
        'requests': 'list[str]'
    }

    attribute_map = {
        'opaque': 'opaque',
        'requests': 'requests'
    }

    def __init__(self, opaque=None, requests=None, local_vars_configuration=None):  # noqa: E501
        """V1DeviceClaimConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._opaque = None
        self._requests = None
        self.discriminator = None

        if opaque is not None:
            self.opaque = opaque
        if requests is not None:
            self.requests = requests

    @property
    def opaque(self):
        """Gets the opaque of this V1DeviceClaimConfiguration.  # noqa: E501


        :return: The opaque of this V1DeviceClaimConfiguration.  # noqa: E501
        :rtype: V1OpaqueDeviceConfiguration
        """
        return self._opaque

    @opaque.setter
    def opaque(self, opaque):
        """Sets the opaque of this V1DeviceClaimConfiguration.


        :param opaque: The opaque of this V1DeviceClaimConfiguration.  # noqa: E501
        :type opaque: V1OpaqueDeviceConfiguration
        """

        self._opaque = opaque

    @property
    def requests(self):
        """Gets the requests of this V1DeviceClaimConfiguration.  # noqa: E501

        Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.  References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.  # noqa: E501

        :return: The requests of this V1DeviceClaimConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._requests

    @requests.setter
    def requests(self, requests):
        """Sets the requests of this V1DeviceClaimConfiguration.

        Requests lists the names of requests where the configuration applies. If empty, it applies to all requests.  References to subrequests must include the name of the main request and may include the subrequest using the format <main request>[/<subrequest>]. If just the main request is given, the configuration applies to all subrequests.  # noqa: E501

        :param requests: The requests of this V1DeviceClaimConfiguration.  # noqa: E501
        :type requests: list[str]
        """

        self._requests = requests

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1DeviceClaimConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1DeviceClaimConfiguration):
            return True

        return self.to_dict() != other.to_dict()
